@@ -25,7 +25,7 @@ from pymatgen.core.structure import Structure
 from pymatgen.transformations.transformation_abc import AbstractTransformation
 
 from pymatgen.io.cifio import CifParser
-from pymatgen.io.vaspio import Poscar
+from pymatgen.io.vaspio.vasp_input import Poscar
 from pymatgen.serializers.json_coders import MSONable
 
 
