@@ -54,7 +54,7 @@ class StructureFitter(object):
     def __init__(self, structure_a, structure_b, tolerance_cell_misfit=0.1,
                  tolerance_atomic_misfit=1.0, supercells_allowed=True,
                  anonymized=False, fitting_accuracy=FAST_FIT,
-                 timeout=600, symmetry_tol=0):
+                 timeout=300, symmetry_tol=0):
         """
         Fits two structures. All fitting parameters have been set with defaults
         that should work in most cases.
@@ -81,12 +81,14 @@ class StructureFitter(object):
                 EXTREME_FIT to set the tradeoff between accuracy and speed. The
                 default FAST_FIT should work reasonably well in most instances.
             timeout:
-                Time out in seconds. Defaults to 10mins.
+                Time out in seconds for generating and testing rotations. Note
+                that the same timeout will apply to generating and testing
+                separately. Defaults to 5 mins, which means a total of 10 mins.
             symmetry_tol:
                 If > 0, symmetry checking is performed on the two structures
                 based on that symmetry tolerance in angstrom. Structures with
                 different symmetries are not fitted to each other. A good value
-                is around 0.1.
+                is around 0.1. Defaults to 0.
         """
 
         self._tolerance_cell_misfit = tolerance_cell_misfit
@@ -108,14 +110,15 @@ class StructureFitter(object):
             sg_a = finder_a.get_spacegroup_number()
             sg_b = finder_b.get_spacegroup_number()
             same_sg = sg_a == sg_b
-            logger.debug("Spacegroup numbers : A - {}, B - {}".format(sg_a, sg_b))
+            logger.debug("Spacegroup numbers: A-{}, B-{}".format(sg_a, sg_b))
 
         if not symmetry_tol or same_sg:
             self._mapping_op = None
             if not self._anonymized:
                 self.fit(self._structure_a, self._structure_b)
                 if self.fit_found:
-                    self.el_mapping = {el:el for el in self._structure_a.composition.elements}
+                    self.el_mapping = {el:el for el \
+                                    in self._structure_a.composition.elements}
             else:
                 comp_a = structure_a.composition
                 comp_b = structure_b.composition
@@ -123,8 +126,10 @@ class StructureFitter(object):
                     el_a = comp_a.elements
                     #Create permutations of the specie/elements in structure A 
                     for p in itertools.permutations(el_a):
-                        # Create mapping of the specie/elements in structure B to that of A.
-                        # Then create a modified structure with those elements and try to fit it.
+                        # Create mapping of the specie/elements in structure B 
+                        # to that of A.
+                        # Then create a modified structure with those elements 
+                        # and try to fit it.
                         el_mapping = dict(zip(comp_b.elements, p))
                         logger.debug("Using specie mapping " + str(el_mapping))
                         mod = StructureEditor(self._structure_b)
@@ -132,10 +137,12 @@ class StructureFitter(object):
                         self.fit(self._structure_a, mod.modified_structure)
                         if self._mapping_op != None:
                             #Store successful element mapping
-                            self.el_mapping = {el_a:el_b for el_b, el_a in el_mapping.items()}
+                            self.el_mapping = {el_a:el_b for el_b, el_a \
+                                               in el_mapping.items()}
                             break
                 else:
-                    logger.debug("No. of elements in structures are unequal.  Cannot be fitted!")
+                    logger.debug("No. of elements in structures are unequal. "
+                                 "Cannot be fitted!")
         elif symmetry_tol:
             self._mapping_op = None
             logger.debug("Symmetry is different.")
@@ -146,62 +153,66 @@ class StructureFitter(object):
         Compares two structures and give the possible affine mapping that
         transforms one into another.
         """
-        biggest_dist = 0
         logger.debug("Structure a")
         logger.debug(str(a))
         logger.debug("Structure b")
         logger.debug(str(b))
-
-        # Check composition first.  If compositions are not the same, do not need to fit further.
-        if a.composition.reduced_formula != b.composition.reduced_formula or ((a.num_sites != b.num_sites) and not self._supercells_allowed):
+        # Check composition first.  If compositions are not the same, do not
+        # need to fit further.
+        if a.composition.reduced_formula != b.composition.reduced_formula or \
+           ((a.num_sites != b.num_sites) and not self._supercells_allowed):
             logger.debug('Compositions do not match')
             return None
 
         logger.debug('Compositions match')
 
-        # Fitting is done by matching sites in one structure (to_fit)
-        # to the other (fixed).  
-        # We set the structure with fewer sites as fixed, 
-        # and scale the structures to the same density
-        (fixed, to_fit) = self._scale_structures(a, b)
-        # Defines the atom misfit tolerance
-        tol_atoms = self._tolerance_atomic_misfit * (3 * 0.7405 * fixed.volume / (4 * math.pi * fixed.num_sites)) ** (1 / 3)
-        logger.debug("Atomic misfit tolerance = %.4f" % (tol_atoms))
+        # This is cheating, but let's try an identity fit first.  
+        # In many situations, e.g., when a structure has been topotatically
+        # delithiated or substituted, you actually can get a very fast answer 
+        # without having to try all rotations.
+        (mapping_op, biggest_dist, oshift) = self.simple_fit(a, b)
 
-        max_sites = float('inf')
-        # determine which type of sites to use for the mapping
-        for sp in to_fit.species_and_occu:
-            sp_sites = [site for site in to_fit if site.species_and_occu == sp]
-            if len(sp_sites) < max_sites:
-                fit_sites = sp_sites
-                max_sites = len(sp_sites)
+        # If we can't do a simple fit, guess we'd have to do the painful process
+        # of finding rotations.
+        if not mapping_op:
+            # Let's sanitize the structures for fitting. This results in more
+            # orthogonal cells, and typically much faster fitting.
+            a = a.copy(sanitize=True)
+            b = b.copy(sanitize=True)
 
-        # Set the arbitrary origin
-        origin = fit_sites[0]
-        logger.debug("Origin = " + str(origin))
+            # Fitting is done by matching sites in one structure (to_fit)
+            # to the other (fixed).  
+            # We set the structure with fewer sites as fixed, 
+            # and scale the structures to the same density
+            (fixed, to_fit) = self._scale_structures(a, b)
+            # Defines the atom misfit tolerance
+            tol_atoms = self._tolerance_atomic_misfit * \
+                        (3 * 0.7405 * fixed.volume / \
+                         (4 * math.pi * fixed.num_sites)) ** (1 / 3)
+            logger.debug("Atomic misfit tolerance = %.4f" % (tol_atoms))
 
-        oshift = SymmOp.from_rotation_matrix_and_translation_vector(np.eye(3), -origin.coords)
-        shifted_to_fit = apply_operation(to_fit, oshift)
-        # This is cheating, but let's try an identity fit first.  In many situations,
-        # E.g., when a structure has been topotatically delithiated or
-        # substituted, you actually can get a very fast answer without having
-        # to try all rotations.
+            max_sites = float('inf')
+            # Determine which type of sites to use for the mapping
+            for sp in to_fit.species_and_occu:
+                sp_sites = [site for site in to_fit \
+                            if site.species_and_occu == sp]
+                if len(sp_sites) < max_sites:
+                    fit_sites = sp_sites
+                    max_sites = len(sp_sites)
 
-        found_map = False
+            # Set the arbitrary origin
+            origin = fit_sites[0]
+            logger.debug("Origin = " + str(origin))
 
-        simple_rots = self._get_simple_rotations(fixed, to_fit)
-        for rot in simple_rots:
-            rot_op = SymmOp.from_rotation_matrix_and_translation_vector(rot,
-                                                            np.array([0, 0, 0]))
-            (found_map, mapping_op, biggest_dist) = self._test_rotation(rot_op, origin,
-                                                fixed, shifted_to_fit, tol_atoms)
-            if found_map:
-                break
+            oshift = SymmOp.from_rotation_matrix_and_translation_vector(np.eye(3),
+                                                                - origin.coords)
+            shifted_to_fit = apply_operation(to_fit, oshift)
 
-        if not found_map:
             #Get candidate rotations
             cand_rot = self._get_candidate_rotations(origin, fixed, to_fit)
 
+            #Reset the clock.
+            self._start_time = time.time()
             logger.debug(" FOUND {} candidate rotations ".format(len(cand_rot)))
             if len(cand_rot) == 0:
                 logger.debug("No candidate rotations found, returning null. ")
@@ -219,9 +230,11 @@ class StructureFitter(object):
         else:
             logger.debug("Identity fitting matched!")
 
-        logger.debug("Done testing in {} secs".format(time.time() - self._start_time))
+        logger.debug("Done testing in {} secs".format(time.time() - \
+                                                      self._start_time))
 
-        self._atomic_misfit = biggest_dist / ((3 * 0.7405 * a.volume / (4 * math.pi * a.num_sites)) ** (1 / 3))
+        self._atomic_misfit = biggest_dist / ((3 * 0.7405 * a.volume / \
+                                (4 * math.pi * a.num_sites)) ** (1 / 3))
 
         if mapping_op != None:
             rot = mapping_op.rotation_matrix # maps toFit to fixed
@@ -232,11 +245,52 @@ class StructureFitter(object):
             # the other way around
             mshift = np.dot(rot, oshift.translation_vector)
             finaltranslation = mapping_op.translation_vector + mshift[0]
-            composite_op = SymmOp.from_rotation_matrix_and_translation_vector(newrot, finaltranslation)
-            self._mapping_op = composite_op if self.fixed_is_a else composite_op.inverse
+            composite_op = SymmOp.from_rotation_matrix_and_translation_vector(
+                                                newrot, finaltranslation)
+            self._mapping_op = composite_op if self.fixed_is_a \
+                                            else composite_op.inverse
             #self._mapping_op = mapping_op
             self._cell_misfit = shear_invariant(p)
 
+    def simple_fit(self, a, b):
+        # Fitting is done by matching sites in one structure (to_fit)
+        # to the other (fixed).  
+        # We set the structure with fewer sites as fixed, 
+        # and scale the structures to the same density
+        (fixed, to_fit) = self._scale_structures(a, b)
+        # Defines the atom misfit tolerance
+        tol_atoms = self._tolerance_atomic_misfit * (3 * 0.7405 * fixed.volume\
+                                  / (4 * math.pi * fixed.num_sites)) ** (1 / 3)
+        logger.debug("Atomic misfit tolerance = %.4f" % (tol_atoms))
+
+        max_sites = float('inf')
+        # determine which type of sites to use for the mapping
+        for sp in to_fit.species_and_occu:
+            sp_sites = [site for site in to_fit if site.species_and_occu == sp]
+            if len(sp_sites) < max_sites:
+                fit_sites = sp_sites
+                max_sites = len(sp_sites)
+
+        # Set the arbitrary origin
+        origin = fit_sites[0]
+        logger.debug("Origin = " + str(origin))
+
+        oshift = SymmOp.from_rotation_matrix_and_translation_vector(np.eye(3),
+                                                               - origin.coords)
+        shifted_to_fit = apply_operation(to_fit, oshift)
+
+
+        simple_rots = self._get_simple_rotations(fixed, to_fit)
+        for rot in simple_rots:
+            rot_op = SymmOp.from_rotation_matrix_and_translation_vector(rot,
+                                                            np.array([0, 0, 0]))
+            (found_map, mapping_op, biggest_dist) = self._test_rotation(rot_op,
+                                    origin, fixed, shifted_to_fit, tol_atoms)
+            if found_map:
+                return (mapping_op, biggest_dist, oshift)
+
+        return (None, None, None)
+
     def _test_rotation(self, rot, origin, fixed, to_fit, tol_atoms):
         tol_atoms_plus = 1.1 * tol_atoms
         found_map = False
@@ -249,25 +303,30 @@ class StructureFitter(object):
                 break
             if site.species_and_occu == origin.species_and_occu:
                 shift = site.coords
-                op = SymmOp.from_rotation_matrix_and_translation_vector(rot.rotation_matrix, shift)
+                op = SymmOp.from_rotation_matrix_and_translation_vector(
+                                                    rot.rotation_matrix, shift)
                 nstruct = apply_operation(to_fit, op)
                 correspondance = OrderedDict()
                 all_match = True
                 biggest_dist = 0
                 # check to see if transformed struct matches fixed structure
                 for trans in nstruct:
-                    cands = fixed.get_sites_in_sphere(trans.coords, tol_atoms_plus)
+                    cands = fixed.get_sites_in_sphere(trans.coords,
+                                                      tol_atoms_plus)
                     if len(cands) == 0:
                         logger.debug("No candidates found.")
                         all_match = False
                         break
                     cands = sorted(cands, key=lambda a: a[1])
                     (closest, closest_dist) = cands[0]
-                    if closest_dist > tol_atoms or closest.species_and_occu != trans.species_and_occu:
-                        logger.debug("Closest dist too large! closest dist = {}".format(closest_dist))
+                    if closest_dist > tol_atoms or \
+                       closest.species_and_occu != trans.species_and_occu:
+                        logger.debug("Closest dist too large! " + \
+                                     "Closest dist = {}".format(closest_dist))
                         all_match = False
                         break
                     correspondance[trans] = closest
+
                     if closest_dist > biggest_dist:
                         biggest_dist = closest_dist
 
@@ -293,25 +352,30 @@ class StructureFitter(object):
                 # elimininates weird situations where two atoms fit to one
                 # (reduced in the unit cell)
                 for fixed_site in fixed:
-                    cands = nstruct.get_sites_in_sphere(fixed_site.coords, tol_atoms_plus)
+                    cands = nstruct.get_sites_in_sphere(fixed_site.coords,
+                                                        tol_atoms_plus)
                     if len(cands) == 0:
-                        logger.debug("Rejected because inverse mapping does not fit - Step 1")
+                        logger.debug("Rejected because inverse mapping does "
+                                     "not fit - Step 1")
                         all_match = False
                         break
 
                     cands = sorted(cands, key=lambda a: a[1])
                     (closest, closest_dist) = cands[0]
 
-                    if closest_dist > tol_atoms or closest.species_and_occu != fixed_site.species_and_occu:
+                    if closest_dist > tol_atoms or \
+                       closest.species_and_occu != fixed_site.species_and_occu:
                         all_match = False
-                        logger.debug("Rejected because inverse mapping does not fit - Step 2")
+                        logger.debug("Rejected because inverse mapping does "
+                                     "not fit - Step 2")
                         break
                     inv_correspondance[fixed_site] = closest
 
                 if all_match:
                     if not are_sites_unique(inv_correspondance.values(), False):
                         all_match = False
-                        logger.debug("Rejected because two atoms fit to the same site for the inverse")
+                        logger.debug("Rejected because two atoms fit to the "
+                                     "same site for the inverse")
                         continue
 
                     self.inv_correspondance = inv_correspondance
@@ -319,12 +383,15 @@ class StructureFitter(object):
                     for k, v in inv_correspondance.items():
                         logger.debug("{} fits on {}".format(k, v))
 
-                    # The smallest correspondance array shouldn't have any equivalent sites
+                    # The smallest correspondance array shouldn't have any 
+                    # equivalent sites
                     if fixed.num_sites != to_fit.num_sites:
                         logger.debug("Testing sites unique")
                         if not are_sites_unique(correspondance.values()):
                             all_match = False
-                            logger.debug("Rejected because the smallest correspondance array has equivallent sites")
+                            logger.debug("Rejected because the smallest "
+                                         "correspondance array has equivallent "
+                                         "sites.")
                             continue
 
                     found_map = True
@@ -342,17 +409,20 @@ class StructureFitter(object):
         output.append("\nStructure 2:")
         output.append(str(self._structure_b))
         output.append("\nFitting parameters:")
-        output.append("\tTolerance cell misfit = " + str(self._tolerance_cell_misfit))
+        output.append("\tTolerance cell misfit = " + \
+                      str(self._tolerance_cell_misfit))
         output.append("\tSupercells allowed = " + str(self._supercells_allowed))
         output.append("\tAnonymized  = " + str(self._anonymized))
-        output.append("\nFitting " + ("succeeded " if self._mapping_op != None else "failed"))
+        output.append("\nFitting " + ("succeeded " if self._mapping_op != None\
+                                                   else "failed"))
         if self._mapping_op != None:
             output.append("\tMapping op = " + str(self._mapping_op))
             output.append("\tCell misfit = " + str(self._cell_misfit))
             output.append("\tAtomic misfit = " + str(self._atomic_misfit))
             if self._anonymized:
                 output.append("Element mapping")
-                output.append("\n".join([str(k) + " -> " + str(v) for k, v in self.el_mapping.items()]))
+                output.append("\n".join([str(k) + " -> " + str(v) \
+                                         for k, v in self.el_mapping.items()]))
         return "\n".join(output)
 
     def _scale_structures(self, a, b):
@@ -367,7 +437,8 @@ class StructureFitter(object):
         rho_b = to_fit.num_sites / to_fit.volume
         scale = (rho_b / rho_a) ** (1 / 3)
         self.scale = scale
-        to_fit = Structure(Lattice(to_fit.lattice.matrix * scale), to_fit.species_and_occu, to_fit.frac_coords)
+        to_fit = Structure(Lattice(to_fit.lattice.matrix * scale),
+                           to_fit.species_and_occu, to_fit.frac_coords)
         return (fixed, to_fit)
 
 
@@ -382,7 +453,8 @@ class StructureFitter(object):
             dr = lengths[i] * math.sqrt(tol_shear / 2)
             shell = to_fit.get_neighbors_in_shell(origin.coords, lengths[i], dr)
             logger.debug("shell {} radius={} dr={}".format(i, lengths[i], dr))
-            shells.append([site for (site, dist) in shell if site.species_and_occu == origin.species_and_occu])
+            shells.append([site for (site, dist) in shell \
+                           if site.species_and_occu == origin.species_and_occu])
             logger.debug("No. in shell = {}".format(len(shells[-1])))
         # now generate candidate rotations
         cand_rot = {} #Dict of SymmOp : float
@@ -391,10 +463,12 @@ class StructureFitter(object):
         c = len(shells[2])
         total_rots = a * b * c
         if total_rots < self._max_rotations:
-            logger.debug("Total rots = {}. Using all rotations.".format(total_rots))
+            logger.debug("Total rots = {}. Using all rotations.".format(
+                                                                   total_rots))
             test_rotations = itertools.product(*shells)
         else:
-            logger.warning("Total rots = {m} exceed max_rotations = {n}. Using {n} randomly selected rotations.".format(m=total_rots, n=self._max_rotations))
+            logger.warning("Total rots={m} exceed max_rotations={n}.".format(
+                                        m=total_rots, n=self._max_rotations))
             def random_rot():
                 considered_rots = []
                 while len(considered_rots) < self._max_rotations:
@@ -405,23 +479,27 @@ class StructureFitter(object):
             test_rotations = random_rot()
 
         for pool in test_rotations:
-            if all([nn.species_and_occu == origin.species_and_occu for nn in pool]):
-                # now, can a unitary transformation bring the cell vectors together
-                cell_v = np.array([nn.coords - origin.coords for nn in pool]).transpose()
+            if all([nn.species_and_occu == origin.species_and_occu \
+                    for nn in pool]):
+                # Can a unitary transformation bring the cell vectors together?
+                coords = [nn.coords - origin.coords for nn in pool]
+                cell_v = np.array(coords).transpose()
                 det = np.linalg.det(cell_v)
                 if abs(det) < 0.001 or abs(abs(det) - fixed.volume) > 0.01:
                     continue
                 rot = np.dot(fixed_basis, np.linalg.inv(cell_v))
-                r = SymmOp.from_rotation_matrix_and_translation_vector(rot, np.array([0, 0, 0]))
+                r = SymmOp.from_rotation_matrix_and_translation_vector(rot,
+                                                        np.array([0, 0, 0]))
 
                 if r not in cand_rot:
                     transf = r.rotation_matrix
                     transf = np.dot(transf.transpose(), transf)
 
-                    #This resolves a very very strange bug in numpy that causes
-                    #random eigenvectors to be returned for matrices very very
-                    #close to the identity matrix.
-                    transf = np.eye(3) if np.allclose(transf, np.eye(3)) else transf
+                    # This resolves a very very strange bug in numpy that causes
+                    # random eigenvectors to be returned for matrices very very
+                    # close to the identity matrix.
+                    transf = np.eye(3) if np.allclose(transf, np.eye(3)) \
+                                       else transf
                     pbis = sqrt_matrix(transf)
                     if shear_invariant(pbis) < tol_shear:
                         cand_rot[r] = shear_invariant(pbis)
@@ -437,8 +515,10 @@ class StructureFitter(object):
         for i in xrange(3):
             if abs(a1[i] - a2[i]) > 5:
                 return []
-        fixed_unit_matrix = np.array([row / np.linalg.norm(row) for row in fixed.lattice.matrix])
-        to_fit_unit_matrix = np.array([row / np.linalg.norm(row) for row in to_fit.lattice.matrix])
+        fixed_unit_matrix = np.array([row / np.linalg.norm(row) \
+                                      for row in fixed.lattice.matrix])
+        to_fit_unit_matrix = np.array([row / np.linalg.norm(row) \
+                                       for row in to_fit.lattice.matrix])
         possible_rots = []
         inv_fixed = np.linalg.inv(fixed_unit_matrix.transpose())
         for p in itertools.permutations(to_fit_unit_matrix):
@@ -538,7 +618,8 @@ def are_sites_unique(sites, allow_periodic_image=True):
     for (site1, site2) in itertools.combinations(sites, 2):
         if allow_periodic_image and site1.is_periodic_image(site2):
             return False
-        if site1.species_and_occu == site2.species_and_occu and (abs(site1.coords - site2.coords) < 0.1).all():
+        if site1.species_and_occu == site2.species_and_occu and \
+           (abs(site1.coords - site2.coords) < 0.1).all():
             return False
     return True
 
