@@ -22,13 +22,13 @@ from pymatgen.util.string_utils import formula_double_format
 from pymatgen.serializers.json_coders import MSONable
 
 
-def _load__pt_data():
+def _load_pt_data():
     """Loads element data from json file"""
     module_dir = os.path.dirname(os.path.abspath(__file__))
-    with open(os.path.join(module_dir, "periodic_table.json")) as f:
+    with open(os.path.join(module_dir, "resources", "periodic_table.json")) as f:
         return json.load(f)
 
-_pt_data = _load__pt_data()
+_pt_data = _load_pt_data()
 _pt_row_sizes = (2, 8, 8, 18, 18, 32, 32)
 
 
@@ -56,10 +56,10 @@ class Element(object):
         object.__setattr__(self, '_x', self._data.get('X', 0))
 
     def __setattr__(self, n, v):
-        raise ValueError("Element is immutable and setting of attributes is not allowed")
+        raise ValueError("Element is immutable.")
 
     def __delattr__(self, n):
-        raise ValueError("Element is immutable and deleting of attributes is not allowed")
+        raise ValueError("Element is immutable.")
 
     @property
     def average_ionic_radius(self):
