@@ -21,8 +21,10 @@ import os
 import abc
 import ConfigParser
 import json
+import re
 
-from pymatgen.io.vaspio import Incar, Poscar, Potcar, Kpoints
+from pymatgen.io.vaspio.vasp_input import Incar, Poscar, Potcar, Kpoints
+from pymatgen.io.cifio import CifWriter
 
 
 class AbstractVaspInputSet(object):
@@ -147,27 +149,45 @@ class VaspInputSet(AbstractVaspInputSet):
     4. Lastly, the element symbol itself is checked in the config file. If
        there are no settings, VASP's default of 0.6 is used.
     """
-    def __init__(self, name, config=None):
+    def __init__(self, name, config_file=None, user_incar_settings=None):
+        """
+        Args:
+            name:
+                The name in the config file.
+            config_file:
+                The config file to use. If None (the default), a default config
+                file containing Materials Project and MIT parameters is used.
+            user_incar:
+                User INCAR settings. This allows a user to override INCAR
+                settings, e.g., setting a different MAGMOM for various elements
+                or species.
+        """
         self.name = name
-        if config is None:
+        if config_file is None:
             module_dir = os.path.dirname(os.path.abspath(__file__))
-            self._config = ConfigParser.SafeConfigParser()
-            self._config.optionxform = str
-            self._config.readfp(open(os.path.join(module_dir, "VaspInputSets.cfg")))
-        else:
-            self._config = config
+            config_file = os.path.join(module_dir, "VaspInputSets.cfg")
+        self._config = ConfigParser.SafeConfigParser()
+        self._config.optionxform = str
+        self._config.readfp(open(config_file))
+
         self.potcar_settings = dict(self._config.items(self.name + 'POTCAR'))
         self.kpoints_settings = dict(self._config.items(self.name + 'KPOINTS'))
         self.incar_settings = dict(self._config.items(self.name + 'INCAR'))
         for key in ['MAGMOM', 'LDAUU', 'LDAUJ', 'LDAUL']:
             if key in self.incar_settings:
                 self.incar_settings[key] = json.loads(self.incar_settings[key])
+        self.user_incar_settings = user_incar_settings if user_incar_settings \
+                                   else {}
 
     def get_incar(self, structure):
         incar = Incar()
-        symamt = structure.composition.to_dict
+        comp = structure.composition
+        elements = sorted([el for el in comp.elements if comp[el] > 0], key=lambda el: el.X)
+        most_electroneg = elements[-1].symbol
         poscar = Poscar(structure)
         for key, setting in self.incar_settings.items():
+            if key in self.user_incar_settings:
+                setting = self.user_incar_settings[key]
             if key == "MAGMOM":
                 mag = []
                 for site in structure:
@@ -180,9 +200,9 @@ class VaspInputSet(AbstractVaspInputSet):
                     else:
                         mag.append(setting.get(site.specie.symbol, 0.6))
                 incar[key] = mag
-            elif key in ['LDAUU', 'LDAUJ', 'LDAUL']:
-                if symamt.get("O", 0) > 0 or symamt.get("F", 0) > 0:
-                    incar[key] = [setting.get(sym, 0) for sym in poscar.site_symbols]
+            elif key in ('LDAUU', 'LDAUJ', 'LDAUL'):
+                if most_electroneg in setting.keys():
+                    incar[key] = [setting[most_electroneg].get(sym, 0) for sym in poscar.site_symbols]
                 else:
                     incar[key] = [0 for sym in poscar.site_symbols]
             elif key == "EDIFF":
@@ -257,16 +277,18 @@ class MITVaspInputSet(VaspInputSet):
     2011, 50(8), 2295-2310. 
     doi:10.1016/j.commatsci.2011.02.023 for more information.
     """
-    def __init__(self):
-        super(MITVaspInputSet, self).__init__("MITMatgen")
+    def __init__(self, user_incar_settings=None):
+        VaspInputSet.__init__(self, "MITMatgen",
+                              user_incar_settings=user_incar_settings)
 
 
 class MITHSEVaspInputSet(VaspInputSet):
     """
     Typical implementation of input set for a HSE run.
     """
-    def __init__(self):
-        super(MITHSEVaspInputSet, self).__init__("MITHSE")
+    def __init__(self, user_incar_settings=None):
+        VaspInputSet.__init__(self, "MITHSE",
+                              user_incar_settings=user_incar_settings)
 
 
 class MaterialsProjectVaspInputSet(VaspInputSet):
@@ -278,5 +300,51 @@ class MaterialsProjectVaspInputSet(VaspInputSet):
     which result in different fitted values (even though the methodology of 
     fitting is exactly the same as the MIT scheme).
     """
-    def __init__(self):
-        super(MaterialsProjectVaspInputSet, self).__init__("MaterialsProject")
+    def __init__(self, user_incar_settings=None):
+        VaspInputSet.__init__(self, "MaterialsProject",
+                              user_incar_settings=user_incar_settings)
+
+
+def batch_write_vasp_input(structures, vasp_input_set, output_dir,
+                           make_dir_if_not_present=True, subfolder=None,
+                           sanitize=False, include_cif=False):
+    """
+    Batch write vasp input for a sequence of structures to 
+    output_dir, following the format output_dir/{group}/{formula}_{number}.
+    
+    Args:
+        structures:
+            Sequence of Structures.
+        vasp_input_set:
+            pymatgen.io.vaspio_set.VaspInputSet like object that creates
+            vasp input files from structures
+        output_dir:
+            Directory to output files
+        create_directory:
+            Create the directory if not present. Defaults to True.
+        subfolder:
+            function to create subdirectory name from structure.
+            Defaults to simply "formula_count".
+        sanitize:
+            Boolean indicating whether to sanitize the structure before
+            writing the VASP input files. Sanitized output are generally easier
+            for viewing and certain forms of analysis. Defaults to False.
+        include_cif:
+            Boolean indication whether to output a CIF as well. CIF files are
+            generally better supported in visualization programs.
+    """
+    for i, s in enumerate(structures):
+        formula = re.sub("\s+", "", s.formula)
+        if subfolder is not None:
+            subdir = subfolder(s)
+            dirname = os.path.join(output_dir, subdir)
+        else:
+            dirname = os.path.join(output_dir, '{}_{}'.format(formula, i))
+        if sanitize:
+            s = s.copy(sanitize=True)
+        vasp_input_set.write_input(s, dirname,
+                                make_dir_if_not_present=make_dir_if_not_present)
+        if include_cif:
+            writer = CifWriter(s)
+            writer.write_file(os.path.join(dirname, "{}_{}.cif".format(formula,
+                                                                       i)))
