@@ -8,20 +8,35 @@ from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
-__version__ = "1.0"
+__version__ = "1.1"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __status__ = "Production"
-__date__ = "Sep 23, 2011"
+__date__ = "May 16, 2012"
 
 import numpy as np
+import itertools
+
 from pymatgen.core.structure import Composition
 from pymatgen.phasediagram.pdmaker import PhaseDiagram, GrandPotentialPhaseDiagram
 from pymatgen.analysis.reaction_calculator import Reaction
+from pymatgen.comp_geometry.simplex import Simplex
+
 
 class PDAnalyzer(object):
     """
     A class for performing analyses on Phase Diagrams.
+    
+    The algorithm is based on the work in the following papers:
+    
+    1. S. P. Ong, L. Wang, B. Kang, and G. Ceder, Li-Fe-P-O2 Phase Diagram from
+       First Principles Calculations. Chem. Mater., 2008, 20(5), 1798-1807.
+       doi:10.1021/cm702327g
+       
+    2. S. P. Ong, A. Jain, G. Hautier, B. Kang, G. Ceder, Thermal stabilities
+       of delithiated olivine MPO4 (M=Fe, Mn) cathodes investigated using first
+       principles calculations. Electrochem. Comm., 2010, 12(3), 427-430. 
+       doi:10.1016/j.elecom.2010.01.010
     """
 
     numerical_tol = 1e-8
@@ -35,34 +50,27 @@ class PDAnalyzer(object):
 
     def _make_comp_matrix(self, complist):
         """
-        Helper function to generates a normalized composition matrix from a list of composition.
+        Helper function to generates a normalized composition matrix from a
+        list of compositions.
         """
         return np.array([[comp.get_atomic_fraction(el) for el in self._pd.elements] for comp in complist])
 
     def _in_facet(self, facet, comp):
         """
-        Checks if a composition is in a facet using the standard barycentric coordinate system algorithm.
-        The general concept is that the facets from a convex hull form a simplex in n-dimensional space.
-        Taking an arbitrary vertex as an origin, we compute the basis for the simplex from this origin by
-        subtracting all other vertices from the origin. We then project the composition into this 
-        coordinate system and determine the coefficients in this coordinate system.  If the coeffs satisfy
-        that all coeffs >= 0 and sum(coeffs) <= 1, the composition is in the facet.
-        For example, take a 4-comp PD where the facets are tetrahedrons. For a tetrahedron, let's label
-        the vertices as O, A, B anc C.  Let's call our comp coordinate as X.
-        We form the composition matrix M with vectors OA, OB and OB, transponse it, and solve for 
-            M'.a = OX
-        where a are the coefficients.
-        if (a >= 0).all() and sum(a) <= 1, X is in the tetrahedron.
-        Note that in reality, the test needs to provide a tolerance (set to 1e-8 by default) for numerical errors.
+        Checks if a composition is in a facet.
+        
+        Args:
+            facet:
+                facet to test.
+            comp:
+                Composition to test.
         """
         dim = len(self._pd.elements)
         if dim > 1:
-            origin = np.array(self._pd.qhull_data[facet[0]][0:dim - 1])
-            cm = np.array([np.array(self._pd.qhull_data[facet[i]][0:dim - 1]) - origin for i in xrange(1, len(facet))])
-            row = [comp.get_atomic_fraction(self._pd.elements[i]) for i in xrange(1, len(self._pd.elements))]
-            compm = np.array(row) - origin
-            coeffs = np.linalg.solve(cm.transpose(), compm)
-            return (coeffs >= -PDAnalyzer.numerical_tol).all() and sum(coeffs) <= (1 + PDAnalyzer.numerical_tol)
+            coords = [np.array(self._pd.qhull_data[facet[i]][0:dim - 1]) for i in xrange(len(facet))]
+            simplex = Simplex(coords)
+            comp_point = [comp.get_atomic_fraction(self._pd.elements[i]) for i in xrange(1, len(self._pd.elements))]
+            return simplex.in_simplex(comp_point, PDAnalyzer.numerical_tol)
         else:
             return True
 
@@ -90,7 +98,8 @@ class PDAnalyzer(object):
         Provides the decomposition at a particular composition
         
         Args:
-            comp - A composition
+            comp:
+                A composition
         
         Returns:
             Decomposition as a dict of {PDEntry: amount}
@@ -116,7 +125,8 @@ class PDAnalyzer(object):
                 A PDEntry like object
         
         Returns:
-            (decomp, energy above convex hull)  Stable entries should have energy above hull of 0.
+            (decomp, energy above convex hull)  Stable entries should have
+            energy above hull of 0.
         """
         comp = entry.composition
         eperatom = entry.energy_per_atom
@@ -134,51 +144,69 @@ class PDAnalyzer(object):
             entry - A PDEntry like object
         
         Returns:
-            Energy above convex hull of entry. Stable entries should have energy above hull of 0.
+            Energy above convex hull of entry. Stable entries should have
+            energy above hull of 0.
         """
         return self.get_decomp_and_e_above_hull(entry)[1]
 
-
     def get_equilibrium_reaction_energy(self, entry):
         """
-        Provides the reaction energy of a stable entry from the neighboring equilibrium stable entries.
-        (also known as the inverse distance to hull).
+        Provides the reaction energy of a stable entry from the neighboring
+        equilibrium stable entries (also known as the inverse distance to hull).
         
         Args:
             entry:
                 A PDEntry like object
         
         Returns:
-            Equilibrium reaction energy of entry.  Stable entries should have equilibrium reaction energy <= 0.
+            Equilibrium reaction energy of entry. Stable entries should have
+            equilibrium reaction energy <= 0.
         """
         if entry not in self._pd.stable_entries:
             raise ValueError("Equilibrium reaction energy is available only for stable entries.")
-        entries = [e for e in self._pd.all_entries if e != entry]
+        if entry.is_element:
+            return 0
+        entries = [e for e in self._pd.stable_entries if e != entry]
         modpd = PhaseDiagram(entries, self._pd.elements)
         analyzer = PDAnalyzer(modpd)
         return analyzer.get_decomp_and_e_above_hull(entry)[1]
 
+    def get_facet_chempots(self, facet):
+        """
+        Calculates the chemical potentials for each element within a facet.
+        
+        Args:
+            facet:
+                Facet of the phase diagram.
+        
+        Returns:
+            { element: chempot } for all elements in the phase diagram.
+        """
+        complist = [self._pd.qhull_entries[i].composition for i in facet]
+        energylist = [self._pd.qhull_entries[i].energy_per_atom for i in facet]
+        m = self._make_comp_matrix(complist)
+        chempots = np.dot(np.linalg.inv(m), energylist)
+        return dict(zip(self._pd.elements, chempots))
+
     def get_transition_chempots(self, element):
         """
         Get the critical chemical potentials for an element in the Phase Diagram.
         
         Args:
             element:
-                An element.  Has to be in the PD in the first place.
+                An element. Has to be in the PD in the first place.
         
         Returns:
-            A sorted sequence of critical chemical potentials, from less negative to more negative.
+            A sorted sequence of critical chemical potentials, from less
+            negative to more negative.
         """
         if element not in self._pd.elements:
             raise ValueError("get_transition_chempots can only be called with elements in the phase diagram.")
-        ind = self._pd.elements.index(element)
+
         critical_chempots = []
         for facet in self._pd.facets:
-            complist = [self._pd.qhull_entries[i].composition for i in facet]
-            energylist = [self._pd.qhull_entries[i].energy_per_atom for i in facet]
-            m = self._make_comp_matrix(complist)
-            chempots = np.dot(np.linalg.inv(m), energylist)
-            critical_chempots.append(chempots[ind])
+            chempots = self.get_facet_chempots(facet)
+            critical_chempots.append(chempots[element])
 
         clean_pots = []
         for c in sorted(critical_chempots):
@@ -190,20 +218,27 @@ class PDAnalyzer(object):
         clean_pots.reverse()
         return tuple(clean_pots)
 
-    def get_element_profile(self, element, comp):
+    def get_element_profile(self, element, comp, comp_tol=1e-5):
         """
         Provides the element evolution data for a composition.
-        For example, can be used to analyze Li conversion voltages by varying uLi and looking at the phases formed.
-        Also can be used to analyze O2 evolution by varying uO2.
+        For example, can be used to analyze Li conversion voltages by varying
+        uLi and looking at the phases formed. Also can be used to analyze O2
+        evolution by varying uO2.
         
         Args:
             element:
                 An element. Must be in the phase diagram.
             comp:
                 A Composition
+            comp_tol:
+                The tolerance to use when calculating decompositions. Phases
+                with amounts less than this tolerance are excluded. Defaults to
+                1e-5.
         
         Returns:
-            Evolution data as a list of dictionaries of the following format: [ {'chempot': -10.487582010000001, 'evolution': -2.0, 'reaction': Reaction Object], ...]
+            Evolution data as a list of dictionaries of the following format:
+            [ {'chempot': -10.487582010000001, 'evolution': -2.0,
+            'reaction': Reaction Object], ...]
         """
         if element not in self._pd.elements:
             raise ValueError("get_transition_chempots can only be called with elements in the phase diagram.")
@@ -221,10 +256,13 @@ class PDAnalyzer(object):
             return True
 
         for c in chempots:
-            gcpd = GrandPotentialPhaseDiagram(stable_entries, {element:c - 0.01}, self._pd.elements)
+            gcpd = GrandPotentialPhaseDiagram(stable_entries, {element:c - 0.01},
+                                              self._pd.elements)
             analyzer = PDAnalyzer(gcpd)
-            decomp = [gcentry.original_entry.composition for gcentry, amt in analyzer.get_decomposition(gccomp).items() if amt > 1e-5]
-            decomp_entries = [gcentry.original_entry for gcentry, amt in analyzer.get_decomposition(gccomp).items() if amt > 1e-5]
+            decomp = [gcentry.original_entry.composition for gcentry,
+                      amt in analyzer.get_decomposition(gccomp).items() if amt > comp_tol]
+            decomp_entries = [gcentry.original_entry for gcentry,
+                              amt in analyzer.get_decomposition(gccomp).items() if amt > comp_tol]
 
             if not are_same_decomp(prev_decomp, decomp):
                 if elcomp not in decomp:
@@ -235,3 +273,45 @@ class PDAnalyzer(object):
                 evolution.append({'chempot':c, 'evolution' :-rxn.coeffs[rxn.all_comp.index(elcomp)], 'element_reference': elref, 'reaction':rxn, 'entries':decomp_entries})
 
         return evolution
+
+    def get_chempot_range_map(self, elements):
+        """
+        Returns a chemical potential range map for each stable entry.
+                
+        Args:
+            elements:
+                Sequence of elements to be considered as independent variables.
+                E.g., if you want to show the stability ranges of all Li-Co-O
+                phases wrt to uLi and uO, you will supply
+                [Element("Li"), Element("O")]
+        
+        Returns:
+            Returns a dict of the form {entry: [simplices]}. The list of 
+            simplices are the sides of the N-1 dim polytope bounding the
+            allowable chemical potential range of each entry.
+        """
+        elrefs = self._pd.el_refs
+        chempot_ranges = {}
+        for entry in self._pd.stable_entries:
+            all_facets = self._get_facets(entry.composition)
+            simplices = []
+            # For each entry, go through all possible combinations of 2 facets.
+            for facets in itertools.combinations(all_facets, 2):
+                # Get the intersection of the 2 facets.
+                inter = set(facets[0]).intersection(set(facets[1]))
+
+                #Check if the intersection has N-1 vertices. if so, add the line
+                #to the list of simplices.
+                if len(inter) == self._pd.dim - 1:
+                    coords = []
+                    for facet in facets:
+                        chempots = self.get_facet_chempots(facet)
+                        coords.append([chempots[el] - elrefs[el].energy_per_atom for el in elements])
+                    sim = Simplex(coords)
+                    simplices.append(sim)
+
+            if len(simplices) > 0:
+                chempot_ranges[entry] = simplices
+
+        return chempot_ranges
+
